@@ -7,7 +7,7 @@ use SVG::XML;
 use parent qw(SVG::Element SVG::Extension);
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '2.64';
+our $VERSION = '2.87';
 
 =pod
 
@@ -15,7 +15,7 @@ our $VERSION = '2.64';
 
 =head1 NAME
 
-SVG - Perl extension for generating Scalable Vector Graphics (SVG) documents
+SVG - Perl extension for generating Scalable Vector Graphics (SVG) documents.
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ SVG - Perl extension for generating Scalable Vector Graphics (SVG) documents
 
     # use explicit element constructor to generate a group element
     my $y = $svg->group(
-        id    => 'group_y',
+        id => 'group_y',
         style => {
             stroke => 'red',
             fill   => 'green'
@@ -86,8 +86,9 @@ See the other modules in this distribution:
 L<SVG::DOM>,
 L<SVG::XML>,
 L<SVG::Element>,
-L<SVG::Parser>,
-L<SVG::Extension>
+and L<SVG::Extension>.
+
+See L<SVG::Parser> for reading SVG files as C<SVG> objects.
 
 =head2 Converting SVG to PNG and other raster image formats
 
@@ -120,7 +121,7 @@ That you can either embed directly into HTML or can include it using:
 
 =for HTML <p><img src="http://perlmaven.com/img/svg/circle.svg" alt="SVG example circle" /></p>
 
-See also the B<examples> directory in this distribution which contain several fully documented examples.
+See also the B<examples> directory in this distribution which contains several fully documented examples.
 
 =head1 DESCRIPTION
 
@@ -135,15 +136,15 @@ Generating SVG is a simple three step process:
 
 =over 4
 
-=item 1 Construct a new SVG object with L<new>.
+=item 1 Construct a new SVG object with L<"new">.
 
-=item 2 Call element constructors such as L<circle> and L<path> to create SVG elements.
+=item 2 Call element constructors such as L<"circle"> and L<"path"> to create SVG elements.
 
-=item 3 Render the SVG object into XML using the L<xmlify> method.
+=item 3 Render the SVG object into XML using the L<"xmlify"> method.
 
 =back
 
-The L<xmlify> method takes a number of optional arguments that control how SVG
+The L</xmlify> method takes a number of optional arguments that control how SVG
 renders the object into XML, and in particular determine whether a standalone
 SVG document or an inline SVG document fragment is generated:
 
@@ -154,7 +155,7 @@ elements may be optionally specified.
 
 =head2 -inline
 
-An inline SVG document fragment with no DTD that be embedded within other XML
+An inline SVG document fragment with no DTD that is embedded within other XML
 content. As with standalone documents, an alternate namespace may be specified.
 
 No XML content is generated until the third step is reached. Up until this
@@ -165,12 +166,12 @@ from which they can be accessed and modified.
 
 None. However, SVG permits both options and additional element methods to be
 specified in the import list. These options and elements are then available
-for all SVG instances that are created with the L<"new"> constructor. For example,
+for all SVG instances that are created with the L</new> constructor. For example,
 to change the indent string to two spaces per level:
 
     use SVG (-indent => "  ");
 
-With the exception of -auto, all options may also be specified to the L<"new">
+With the exception of -auto, all options may also be specified to the L</new>
 constructor. The currently supported options and their default value are:
 
     # processing options
@@ -240,7 +241,6 @@ Resulting XML snippet:
       <!--
         Generated using the Perl SVG Module V2.50
           by Ronan Oger
-        Info: http://www.roitsystems.com/
       -->
 
 =head1 METHODS
@@ -256,7 +256,7 @@ All element constructors take a hash of element attributes and options;
 element attributes such as 'id' or 'border' are passed by name, while options for the
 method (such as the type of an element that supports multiple alternate forms)
 are passed preceded by a hyphen, e.g '-type'. Both types may be freely
-intermixed; see the L<"fe"> method and code examples througout the documentation
+intermixed; see the L<"fe"> method and code examples throughout the documentation
 for more examples.
 
 =head2 new (constructor)
@@ -271,7 +271,7 @@ a hyphen) may be set on a per object basis:
 
     my $svg2 = SVG->new(id => 'document_element');
 
-    my $svg3 = SVG->new(s
+    my $svg3 = SVG->new(
         -printerror => 1,
         -raiseerror => 0,
         -indent     => '  ',
@@ -285,6 +285,8 @@ a hyphen) may be set on a per object basis:
         height      => 200,
     );
 
+B<SVG instance represents the document and not the C<E<lt>svgE<gt>> root element.>
+
 Default SVG options may also be set in the import list. See L<"EXPORTS"> above
 for more on the available options.
 
@@ -305,7 +307,7 @@ may also be set in xmlify, overriding any corresponding values set in the SVG->n
 
 =head2 xmlify (alias: to_xml render serialise serialize)
 
-$string = $svg->xmlify(%attributes);
+    $string = $svg->xmlify(%attributes);
 
 Returns xml representation of svg document.
 
@@ -323,7 +325,7 @@ B<XML Declaration>
 
 =head2 tag (alias: element)
 
-$tag = $svg->tag($name, %attributes)
+    $tag = $svg->tag($name, %attributes)
 
 Generic element generator. Creates the element named $name with the attributes
 specified in %attributes. This method is the basis of most of the explicit
@@ -334,7 +336,7 @@ element generators.
 
 =head2 anchor
 
-$tag = $svg->anchor(%attributes)
+    $tag = $svg->anchor(%attributes)
 
 Generate an anchor element. Anchors are put around objects to make them
 'live' (i.e. clickable). It therefore requires a drawn object or group element
@@ -342,18 +344,25 @@ as a child.
 
 =head3 optional anchor attributes
 
-the following attributes are expected for anchor tags (any any tags which use -href links):
+The following attributes are expected for anchor tags (any any tags which use -href links):
 
 =head2 -href    required
+
 =head2 -type    optional
+
 =head2 -role    optional
+
 =head2 -title   optional
+
 =head2 -show    optional
+
 =head2 -arcrole optional
+
 =head2 -actuate optional
+
 =head2 target   optional
 
-For more information on the options, refer to the w3c XLink specification at 
+For more information on the options, refer to the w3c XLink specification at
 L<http://www.w3.org/TR/xlink/>
 
 B<Example:>
@@ -367,7 +376,7 @@ B<Example:>
 
     );
 
-for more information about the options above, refer to Link  section in the SVG recommendation: L<http://www.w3.org/TR/SVG11/linking.html#Links>
+For more information about the options above, refer to Link  section in the SVG recommendation: L<http://www.w3.org/TR/SVG11/linking.html#Links>
 
     # add a circle to the anchor. The circle can be clicked on.
     $tag->circle(cx => 10, cy => 10, r => 1);
@@ -394,7 +403,7 @@ for more information about the options above, refer to Link  section in the SVG
 
 =head2 circle
 
-$tag = $svg->circle(%attributes)
+    $tag = $svg->circle(%attributes)
 
 Draw a circle at (cx,cy) with radius r.
 
@@ -402,7 +411,7 @@ Draw a circle at (cx,cy) with radius r.
 
 =head2 ellipse
 
-$tag = $svg->ellipse(%attributes)
+    $tag = $svg->ellipse(%attributes)
 
 Draw an ellipse at (cx,cy) with radii rx,ry.
 
@@ -426,7 +435,7 @@ Draw an ellipse at (cx,cy) with radii rx,ry.
         }
     );
 
-See The B<example/ellipse.pl> 
+See The B<example/ellipse.pl>
 
 =for HTML <p><img src="http://perlmaven.com/img/svg/ellipse.svg" alt="SVG example ellipse" /></p>
 
@@ -449,7 +458,7 @@ Draw a rectangle at (x,y) with width 'width' and height 'height' and side radii
 
 =head2 image
 
- $tag = $svg->image(%attributes)
+    $tag = $svg->image(%attributes)
 
 Draw an image at (x,y) with width 'width' and height 'height' linked to image
 resource '-href'. See also L<"use">.
@@ -469,7 +478,7 @@ B<Output:>
 
 =head2 use
 
-$tag = $svg->use(%attributes)
+    $tag = $svg->use(%attributes)
 
 Retrieve the content from an entity within an SVG document and apply it at
 (x,y) with width 'width' and height 'height' linked to image resource '-href'.
@@ -492,10 +501,10 @@ single element within an external SVG file.
 
 =head2 polygon
 
-$tag = $svg->polygon(%attributes)
+    $tag = $svg->polygon(%attributes)
 
 Draw an n-sided polygon with vertices at points defined by a string of the form
-'x1,y1,x2,y2,x3,y3,... xy,yn'. The L<get_path> method is provided as a
+'x1,y1,x2,y2,x3,y3,... xy,yn'. The L<"get_path"> method is provided as a
 convenience to generate a suitable string from coordinate data.
 
     # a five-sided polygon
@@ -516,11 +525,11 @@ convenience to generate a suitable string from coordinate data.
 
 SEE ALSO:
 
-L<polyline>, L<path>, L<get_path>.
+L<"polyline">, L<"path">, L<"get_path">.
 
 =head2 polyline
 
-$tag = $svg->polyline(%attributes)
+    $tag = $svg->polyline(%attributes)
 
 Draw an n-point polyline with points defined by a string of the form
 'x1,y1,x2,y2,x3,y3,... xy,yn'. The L<"get_path"> method is provided as a
@@ -548,7 +557,7 @@ convenience to generate a suitable string from coordinate data.
 
 =head2 line
 
-$tag = $svg->line(%attributes)
+    $tag = $svg->line(%attributes)
 
 Draw a straight line between two points (x1,y1) and (x2,y2).
 
@@ -564,12 +573,12 @@ To draw multiple connected lines, use L<"polyline">.
 
 =head2 text
 
-$text = $svg->text(%attributes)->cdata();
+    $text = $svg->text(%attributes)->cdata();
 
-$text_path = $svg->text(-type=>'path');
-$text_span = $text_path->text(-type=>'span')->cdata('A');
-$text_span = $text_path->text(-type=>'span')->cdata('B');
-$text_span = $text_path->text(-type=>'span')->cdata('C');
+    $text_path = $svg->text(-type=>'path');
+    $text_span = $text_path->text(-type=>'span')->cdata('A');
+    $text_span = $text_path->text(-type=>'span')->cdata('B');
+    $text_span = $text_path->text(-type=>'span')->cdata('C');
 
 Define the container for a text string to be drawn in the image.
 
@@ -602,11 +611,11 @@ B<Input:>
 
 SEE ALSO:
 
-L<desc>, L<cdata>.
+L<"desc">, L<"cdata">.
 
 =head2 title
 
-$tag = $svg->title(%attributes)
+    $tag = $svg->title(%attributes)
 
 Generate the title of the image.
 
@@ -614,7 +623,7 @@ Generate the title of the image.
 
 =head2 desc
 
-$tag = $svg->desc(%attributes)
+    $tag = $svg->desc(%attributes)
 
 Generate the description of the image.
 
@@ -622,7 +631,7 @@ Generate the description of the image.
 
 =head2 comment
 
-$tag = $svg->comment(@comments)
+    $tag = $svg->comment(@comments)
 
 Generate the description of the image.
 
@@ -630,7 +639,7 @@ Generate the description of the image.
 
 =head2 pi (Processing Instruction)
 
-$tag = $svg->pi(@pi)
+    $tag = $svg->pi(@pi)
 
 Generate a set of processing instructions
 
@@ -643,7 +652,7 @@ Generate a set of processing instructions
 
 =head2 script
 
-$tag = $svg->script(%attributes)
+    $tag = $svg->script(%attributes)
 
 Generate a script container for dynamic (client-side) scripting using
 ECMAscript, Javascript or other compatible scripting language.
@@ -667,10 +676,10 @@ ECMAscript, Javascript or other compatible scripting language.
 
 =head2 path
 
-$tag = $svg->path(%attributes)
+    $tag = $svg->path(%attributes)
 
 Draw a path element. The path vertices may be provided as a parameter or
-calculated using the L<get_path> method.
+calculated using the L<"get_path"> method.
 
     # a 10-pointsaw-tooth pattern drawn with a path definition
     my $xv = [0,1,2,3,4,5,6,7,8,9];
@@ -694,11 +703,11 @@ calculated using the L<get_path> method.
     );
 
 
-SEE ALSO: L<get_path>.
+SEE ALSO: L<"get_path">.
 
 =head2 get_path
 
-$path = $svg->get_path(%attributes)
+    $path = $svg->get_path(%attributes)
 
 Returns the text string of points correctly formatted to be incorporated into
 the multi-point SVG drawing object definitions (path, polyline, polygon)
@@ -740,7 +749,7 @@ B<Aliases:> get_path set_path
 
 =head2 animate
 
-$tag = $svg->animate(%attributes)
+    $tag = $svg->animate(%attributes)
 
 Generate an SMIL animation tag. This is allowed within any nonempty tag. Refer
 to the W3C for detailed information on the subtleties of the animate SMIL
@@ -797,7 +806,7 @@ B<Inputs:> -method = Transform | Motion | Color
 
 =head2 group
 
-$tag = $svg->group(%attributes)
+    $tag = $svg->group(%attributes)
 
 Define a group of objects with common properties. Groups can have style,
 animation, filters, transformations, and mouse actions assigned to them.
@@ -814,7 +823,7 @@ animation, filters, transformations, and mouse actions assigned to them.
 
 =head2 defs
 
-$tag = $svg->defs(%attributes)
+    $tag = $svg->defs(%attributes)
 
 define a definition segment. A Defs requires children when defined using SVG.pm
 
@@ -822,14 +831,14 @@ define a definition segment. A Defs requires children when defined using SVG.pm
 
 =head2 style
 
-$svg->tag('style', %styledef);
+    $svg->tag('style', %styledef);
 
-Sets/Adds style-definition for the following objects being created.
+Sets/adds style-definition for the following objects being created.
 
 Style definitions apply to an object and all its children for all properties for
 which the value of the property is not redefined by the child.
 
-  $tag = $SVG->style(%attributes)
+    $tag = $SVG->style(%attributes)
 
 Generate a style container for inline or xlink:href based styling instructions
 
@@ -845,24 +854,21 @@ Generate a style container for inline or xlink:href based styling instructions
         ellipse  fill:none;stroke:yellow;
         text     fill:black;stroke:none;
     });
-    
+
     # Create a external CSS stylesheet reference
     my $tag2 = $SVG->style(type=>"text/css", -href="/resources/example.css");
 
-=pod
-
-
 =head2 mouseaction
 
-$svg->mouseaction(%attributes)
+    $svg->mouseaction(%attributes)
 
 Sets/Adds mouse action definitions for tag
 
 =head2 attrib
 
-  $svg->attrib($name, $value)
+    $svg->attrib($name, $value)
 
-Sets/Adds attributes of an element.
+Sets/adds attributes of an element.
 
 Retrieve an attribute:
 
@@ -886,11 +892,11 @@ Remove an attribute:
 
 B<Aliases:> attr attribute
 
-Sets/Replaces attributes for a tag.
+Sets/replaces attributes for a tag.
 
 =head2 cdata
 
-$svg->cdata($text)
+    $svg->cdata($text)
 
 Sets cdata to $text. SVG.pm allows you to set cdata for any tag. If the tag is
 meant to be an empty tag, SVG.pm will not complain, but the rendering agent will
@@ -912,20 +918,20 @@ B<Result:>
 
 SEE ALSO:
 
-L<CDATA>, L<desc>, L<title>, L<text>, L<script>.
+L<"CDATA">, L<"desc">, L<"title">, L<"text">, L<"script">.
 
 =head2 cdata_noxmlesc
 
- $script = $svg->script();
- $script->cdata_noxmlesc($text);
+    $script = $svg->script();
+    $script->cdata_noxmlesc($text);
 
 Generates cdata content for text and similar tags which do not get xml-escaped.
 In othe words, does not parse the content and inserts the exact string into the cdata location.
 
 =head2 CDATA
 
- $script = $svg->script();
- $script->CDATA($text);
+    $script = $svg->script();
+    $script->CDATA($text);
 
 Generates a <![CDATA[ ... ]]> tag with the contents of $text rendered exactly as supplied. SVG.pm allows you to set cdata for any tag. If the tag is
 meant to be an empty tag, SVG.pm will not complain, but the rendering agent will
@@ -978,13 +984,13 @@ B<Result:>
         }
         ]]E<gt>
 
-SEE ALSO: L<cdata>, L<script>.
+SEE ALSO: L<"cdata">, L<"script">.
 
 =head2 xmlescp and xmlescape
 
-$string = $svg->xmlescp($string)
-$string = $svg->xmlesc($string)
-$string = $svg->xmlescape($string)
+    $string = $svg->xmlescp($string)
+    $string = $svg->xmlesc($string)
+    $string = $svg->xmlescape($string)
 
 SVG module does not xml-escape characters that are incompatible with the XML specification. B<xmlescp> and B<xmlescape> provides this functionality. It is a helper function which generates an XML-escaped string for reserved characters such as ampersand, open and close brackets, etcetera.
 
@@ -1001,7 +1007,7 @@ The behaviour of xmlesc is to apply the following transformation to the input st
 
 =head2 filter
 
-$tag = $svg->filter(%attributes)
+    $tag = $svg->filter(%attributes)
 
 Generate a filter. Filter elements contain L<"fe"> filter sub-elements.
 
@@ -1016,16 +1022,16 @@ Generate a filter. Filter elements contain L<"fe"> filter sub-elements.
 
     $filter->fe();
 
-SEE ALSO: L<fe>.
+SEE ALSO: L<"fe">.
 
 =head2 fe
 
-$tag = $svg->fe(-type=>'type', %attributes)
+    $tag = $svg->fe(-type=>'type', %attributes)
 
 Generate a filter sub-element. Must be a child of a L<"filter"> element.
 
     my $fe = $svg->fe(
-        -type     => 'DiffuseLighting'  # required - element name omiting 'fe'
+        -type     => 'DiffuseLighting'  # required - element name omitting 'fe'
         id        => 'filter_1',
         style     => {
             'font'      => [ qw(Arial Helvetica sans) ],
@@ -1088,15 +1094,14 @@ Also note that the elelemts are defined in lower case in the module, but as of v
 =head2 * feTurbulence
 
 
-SEE ALSO: L<filter>.
+SEE ALSO: L<"filter">.
 
 =head2 pattern
 
-$tag = $svg->pattern(%attributes)
+    $tag = $svg->pattern(%attributes)
 
 Define a pattern for later reference by url.
 
-
     my $pattern = $svg->pattern(
         id     => "Argyle_1",
         width  => "50",
@@ -1107,7 +1112,7 @@ Define a pattern for later reference by url.
 
 =head2 set
 
-$tag = $svg->set(%attributes)
+    $tag = $svg->set(%attributes)
 
 Set a definition for an SVG object in one section, to be referenced in other
 sections as needed.
@@ -1122,7 +1127,7 @@ sections as needed.
 
 =head2 stop
 
-$tag = $svg->stop(%attributes)
+    $tag = $svg->stop(%attributes)
 
 Define a stop boundary for L<"gradient">
 
@@ -1136,7 +1141,7 @@ Define a stop boundary for L<"gradient">
 
 =head2 gradient
 
-$tag = $svg->gradient(%attributes)
+    $tag = $svg->gradient(%attributes)
 
 Define a color gradient. Can be of type B<linear> or B<radial>
 
@@ -1200,7 +1205,7 @@ The following elements are generically supported by SVG:
 
 =head2 * vkern
 
-See e.g. L<"pattern"> for an example of the use of these methods.
+See e.g. L</pattern> for an example of the use of these methods.
 
 =head1 METHODS IMPORTED BY SVG::DOM
 
@@ -1252,7 +1257,6 @@ The following L<SVG::DOM> elements are accessible through SVG:
 
 =head2 * cloneNode
 
-
 =cut
 
 #-------------------------------------------------------------------------------
@@ -1281,7 +1285,7 @@ my %default_attrs = (
     -xml_xlink => 'http://www.w3.org/1999/xlink',
     -standalone => 'yes',
     -pubid      => '-//W3C//DTD SVG 1.0//EN',    # formerly -identifier
-    -sysid => 'http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd',
+    -sysid      => 'http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd',
 );
 
 sub import {
@@ -1336,7 +1340,7 @@ All element constructors take a hash of element attributes and options;
 element attributes such as 'id' or 'border' are passed by name, while options for the
 method (such as the type of an element that supports multiple alternate forms)
 are passed preceded by a hyphen, e.g '-type'. Both types may be freely
-intermixed; see the L<"fe"> method and code examples througout the documentation
+intermixed; see the L<"fe"> method and code examples throughout the documentation
 for more examples.
 
 =head2 new (constructor)
@@ -1484,10 +1488,13 @@ sub xmlify {
     my $credits = '';
 
     # Give the module and myself credit unless explicitly turned off
-    unless ( $self->{-docref}->{-nocredits} ) {
+    unless ( $self->{-docref}->{-nocredits}
+        or $self->{-docref}{-creditsinserted} )
+    {
         $self->comment(
-            "\n\tGenerated using the Perl SVG Module V$VERSION\n\tby Ronan Oger\n\tInfo: http://www.roitsystems.com/\n"
+            "\n\tGenerated using the Perl SVG Module V$VERSION\n\tby Ronan Oger\n\n\t"
         );
+        $self->{-docref}{-creditsinserted} = 1;
     }
 
     foreach my $key ( keys %attrs ) {
@@ -1545,10 +1552,10 @@ patches, testing, suggestions, and other nice tidbits:
 
 Peter Wainwright, Excellent ideas, beta-testing, writing SVG::Parser and much of SVG::DOM.
 Fredo, http://www.penguin.at0.net/~fredo/ - provided example code and initial feedback for early SVG.pm versions and the idea of a simplified svg generator.
-Adam Schneider,
-Brial Pilpré,
+Adam Schneider
+Brial Pilpré
 Ian Hickson
-Steve Lihn,
+Steve Lihn
 Allen Day
 Martin Owens - SVG::DOM improvements in version 3.34
 
@@ -1576,9 +1583,6 @@ L<SVG::Parser>,
 L<SVG::Extension>
 
 For Commercial Perl/SVG development, refer to the following sites:
-L<ROASP.com: Serverside SVG server|http://www.roitsystems.com/>,
-L<ROIT Systems: Commercial SVG perl solutions|http://www.roitsystems.com/>,
-L<SVG at the W3C|http://www.w3c.org/Graphics/SVG/>
+L<SVG at the W3C|http://www.w3c.org/Graphics/SVG/>.
 
 =cut
-
