@@ -4,7 +4,7 @@ use warnings;
 
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '2.64';
+our $VERSION = '2.87';
 
 # this module extends SVG::Element
 package SVG::Element;
@@ -542,7 +542,7 @@ sub findChildIndex {
         $index++;
     }
 
-    return -1;                # Child not found
+    return -1;    # Child not found
 }
 
 # ---------------
@@ -605,7 +605,7 @@ sub removeChildAtIndex {
 
 #-------------------------------------------------------------------------------
 
-=pod 
+=pod
 
 =head1 NAME
 
@@ -615,11 +615,11 @@ SVG::DOM - A library of DOM (Document Object Model) methods for SVG objects.
 
 SVG::DOM provides a selection of methods for accessing and manipulating SVG
 elements through DOM-like methods such as getElements, getChildren, getNextSibling
-and so on. 
+and so on.
 
 =head1 SYNOPSIS
 
-    my $svg=new SVG(id=>"svg_dom_synopsis", width=>"100", height=>"100");
+    my $svg=SVG->new(id=>"svg_dom_synopsis", width=>"100", height=>"100");
     my %attributes=$svg->getAttributes;
 
     my $group=$svg->group(id=>"group_1");
@@ -667,18 +667,18 @@ Return a list of all children defined on the current node, or undef if there are
 In scalar context returns an array reference.
 
 Alias: getChildElements(), getChildNodes()
-  
+
 =head2 @children = $obj->hasChildren()
 
 Return 1 if the current node has children, or 0 if there are no children.
 
 Alias: hasChildElements, hasChildNodes()
-  
-=head2 $ref = $obj->getFirstChild() 
+
+=head2 $ref = $obj->getFirstChild()
 
 Return the first child element of the current node, or undef if there are no children.
 
-=head2 $ref = $obj->getLastChild() 
+=head2 $ref = $obj->getLastChild()
 
 Return the last child element of the current node, or undef if there are no children.
 
@@ -721,7 +721,7 @@ Return a string containing the name (i.e. the type, not the ID) of an element.
 
 Alias: getType(), getTagName(), getNodeName()
 
-=head2 $ref = $svg->getElementByID($id) 
+=head2 $ref = $svg->getElementByID($id)
 
 Alias: getElementbyID()
 
@@ -749,7 +749,7 @@ Set attribute $name to $value. If $value is undef, deletes the attribute.
 
 =head2 $cdata = $obj->getCDATA()
 
-Return the cannonical data (i.e. textual content) of the current node.
+Return the canonical data (i.e. textual content) of the current node.
 
 Alias: getCdata(), getData()
 
@@ -775,7 +775,7 @@ Returns 1 if $element was successfully inserted before $obj
 
 =head2 $boolean = $obj->insertSiblingAfter( $element );
 
-Returns 1 if $element was successfully inserted after $obj 
+Returns 1 if $element was successfully inserted after $obj
 
 =head2 $element = $obj->replaceChild( $element, $child );
 
@@ -785,7 +785,7 @@ Returns $child if $element successfully replaced $child in $obj
 
 Returns $child if it was removed successfully from $obj
 
-=head2 $element = $obj->cloneNode( $deep ); 
+=head2 $element = $obj->cloneNode( $deep );
 
 Returns a new $element clone of $obj, without parents or children. If deep is set to 1, all children are included recursively.
 
@@ -798,10 +798,8 @@ Martin Owens, doctormo@postmaster.co.uk
 
 perl(1), L<SVG>, L<SVG::XML>, L<SVG::Element>, L<SVG::Parser>
 
-L<http://www.roitsystems.com/> ROIT Systems: Commercial SVG perl solutions
 L<http://www.w3c.org/Graphics/SVG/> SVG at the W3C
 
 =cut
 
 1;
-
